@@ -36,6 +36,7 @@ from pgn_read.core.constants import (
     PGN_MAXIMUM_LINE_LENGTH,
     PGN_LINE_SEPARATOR,
     PGN_TOKEN_SEPARATOR,
+    DG_DESTINATION,
 )
 
 from .constants import (
@@ -711,13 +712,13 @@ class GameUpdate(_Game):
         pieces = [""] * 64
         bits = 0
         for piece in self._piece_placement_data.values():
-            pieces[piece.square.number] = piece.name
-            bits += piece.square.bit
-        pieces = "".join(pieces)
+            piece_square = piece.square
+            pieces[piece_square.number] = piece.name
+            bits += piece_square.bit
         delta_after = position_delta[1]
         self.positionkeys.append(
             bits.to_bytes(8, "big").decode("iso-8859-1")
-            + pieces
+            + "".join(pieces)
             + delta_after[1]
             + delta_after[3]
             + delta_after[2]
@@ -748,6 +749,16 @@ class GameUpdate(_Game):
                 )
             )
 
+    def _append_fully_disambiguated_piece_move(self, match_, dtfm_match):
+        """Override, append fully disambiguated piece move with hyphen."""
+        self._append_decorated_text(
+            "-".join((match_.group(), dtfm_match.group(DG_DESTINATION)))
+        )
+
+    def _append_piece_move_with_from_square(self, name, from_, destination):
+        """Override, append fully disambiguated piece move with hyphen."""
+        self._append_decorated_text("".join((name, from_, "-", destination)))
+
 
 class GameMergeUpdate(GameUpdate):
     """Prepare indicies after each token has been processed.
@@ -777,9 +788,8 @@ class GameUpdatePosition(_Game):
         pieces = [""] * 64
         bits = 0
         for piece in self._piece_placement_data.values():
-            piece_name = piece.name
             piece_square = piece.square
-            pieces[piece_square.number] = piece_name
+            pieces[piece_square.number] = piece.name
             bits += piece_square.bit
         delta_after = position_delta[1]
         self.positionkeys.append(
@@ -947,14 +957,14 @@ class GameMoveText(MoveText):
 
 
 class GameStore(_Game, GameIndicateCheck):
-    """Add structures to support writing PGN moves to database."""
+    """Add check indicators when writing PGN moves to database."""
 
-    def _append_decorated_text(self, movetext):
-        """Append movetext plus appropriate check indicator to self._text."""
-        self._text.append(movetext)
-        self._append_check_indicator()
+    def _append_fully_disambiguated_piece_move(self, match_, dtfm_match):
+        """Override, append fully disambiguated piece move with hyphen."""
+        self._append_decorated_text(
+            "-".join((match_.group(), dtfm_match.group(DG_DESTINATION)))
+        )
 
-    def _append_decorated_castles_text(self, movetext):
-        """Append movetext plus appropriate check indicator to self._text."""
-        self._text.append(movetext)
-        self._append_check_indicator()
+    def _append_piece_move_with_from_square(self, name, from_, destination):
+        """Override, append fully disambiguated piece move with hyphen."""
+        self._append_decorated_text("".join((name, from_, "-", destination)))
