@@ -26,7 +26,7 @@ from .constants import (
 )
 from .eventspec import EventSpec
 from .blanktext import NonTagBind
-from .score import Score
+from .score import Score, ScoreNoInitialPositionException
 
 
 class ScoreMapToBoardException(Exception):
@@ -80,27 +80,6 @@ class AnalysisScore(Score):
         super().__init__(*a, **ka)
         self.owned_by_game = owned_by_game
 
-    def clear_score(self):
-        """Clear data stuctures for navigating a game score.
-
-        Normally a game is loaded into the Score instance and remains for the
-        lifetime of the instance.  UCI Chess Engine analysis, in particular, is
-        used to refresh the game score snippet in an analysis widget after each
-        navigation event in the main game widget.
-
-        This method allows the Score instance to be reused for many PGN game
-        scores, full games or otherwise.
-
-        """
-        self.variation_number = 0
-        self.varstack = []
-        self.choice_number = 0
-        self.choicestack = []
-        self.position_number = 0
-        self.tagpositionmap = dict()
-        self.previousmovetags = dict()
-        self.nextmovetags = dict()
-
     def _go_to_token(self, event=None):
         """Set position and highlighting for token under pointer in analysis.
 
@@ -175,12 +154,11 @@ class AnalysisScore(Score):
 
         """
         if self.current is None:
-
             # Arises as a consequence of avoiding the exception caught in
             # map_game.
             try:
                 self.board.set_board(self.fen_tag_square_piece_map())
-            except TypeError:
+            except ScoreNoInitialPositionException:
                 return False
 
             self._see_first_move()
@@ -268,7 +246,6 @@ class AnalysisScore(Score):
         if not widget.tag_nextrange(
             ALL_CHOICES, scaffold.start_latest_move, scaffold.end_latest_move
         ):
-
             # start_latest_move will be the second move, at earliest,
             # in current variation except if it is the first move in
             # the game.  Thus the move before start_latest_move using
@@ -399,9 +376,9 @@ class AnalysisScore(Score):
             local_map,
         ) = self.owned_by_game.generate_popup_navigation_maps()
         del local_map[EventSpec.scoresheet_to_analysis]
-        local_map[
-            EventSpec.analysis_to_scoresheet
-        ] = self.owned_by_game.current_item
+        local_map[EventSpec.analysis_to_scoresheet] = (
+            self.owned_by_game.current_item
+        )
         local_map.update(navigation_map)
         self._add_cascade_menu_to_popup(
             "Navigation",
