@@ -57,7 +57,7 @@ class CQL(CQLText, EventBinding):
         """Create Frame and delegate to superclass, then set grid geometry."""
         del boardfont
         panel = tkinter.Frame(
-            master=master, cnf=dict(borderwidth=2, relief=tkinter.RIDGE)
+            master=master, cnf={"borderwidth": 2, "relief": tkinter.RIDGE}
         )
         panel.grid_propagate(False)
         super().__init__(
@@ -151,7 +151,7 @@ class CQL(CQLText, EventBinding):
         return popup
 
     def _export_partial(self, event=None):
-        """Export displayed partial position definition."""
+        """Export displayed CQL query definition."""
         del event
         export_chessql.export_single_position(
             self.score.get("1.0", tkinter.END),
