@@ -81,7 +81,7 @@ class CQLDbDelete(DeleteText, DataDelete):
     @staticmethod
     def _set_item(view, object_):
         """Populate view with the CQL query extracted from object_."""
-        view.cql_statement.process_statement(object_.get_srvalue())
+        view.cql_statement.prepare_cql_statement(object_.get_srvalue())
         view.set_and_tag_item_text()
 
     def dialog_ok(self):
@@ -124,22 +124,20 @@ class CQLDbDelete(DeleteText, DataDelete):
         return super().dialog_ok()
 
     def delete(self, commit=True):
-        """Delegate to superclass to delete record then delete game list."""
-        if commit:
-            self.datasource.dbhome.start_transaction()
-        # Hack to prevent _lmdb interface via lmdb to Symas LMMD crash.
-        # Do a widget navigation action to cause refresh after delete in lmdb.
-        if self.datasource.dbhome.dbenv.__class__.__name__ == "Environment":
-            super().delete_no_refresh(commit=False)
-        else:
-            super().delete(commit=False)
-        cqls = self.ui.partialpositionds(
-            self.ui.base_games.datasource.dbhome,
-            self.ui.base_games.datasource.dbset,
-            self.ui.base_games.datasource.dbset,
-            newrow=None,
+        """Delegate to superclass to delete record then delete game list.
+
+        If commit evaluates False caller is responsible for evaluating
+        CQL queries on the changes.
+
+        """
+        dbhome = self.datasource.dbhome
+        dbhome.mark_cql_statements_evaluated(
+            allexceptkey=self.object.key.recno
         )
-        assert self.object.newrecord is None
-        cqls.forget_cql_statement_games(self.object, commit=False)
+        dbhome.mark_all_games_not_evaluated()
         if commit:
-            self.datasource.dbhome.commit()
+            dbhome.remove_cql_query_match_list_for_query_key(
+                self.object.key.recno
+            )
+        super().delete(commit=commit)
+        dbhome.clear_cql_queries_pending_evaluation()
