@@ -33,9 +33,10 @@ import tkinter
 
 from pgn_read.core.constants import (
     TAG_FEN,
+    TAG_SETUP,
 )
 from pgn_read.core.parser import PGN
-from pgn_read.core.game import generate_fen_for_position
+from pgn_read.core.gamedata import generate_fen_for_position
 
 from ..core.pgn import (
     GameDisplayMoves,
@@ -120,7 +121,7 @@ class Game(Score, EventBinding, AnalysisEventBinding):
         """Create Frame and Board, then delegate, then set grid geometry."""
         self.ui = ui
         panel = tkinter.Frame(
-            master=master, cnf=dict(borderwidth=2, relief=tkinter.RIDGE)
+            master=master, cnf={"borderwidth": 2, "relief": tkinter.RIDGE}
         )
         panel.grid_propagate(False)
         board = Board(panel, boardfont=boardfont, ui=ui)
@@ -246,12 +247,12 @@ class Game(Score, EventBinding, AnalysisEventBinding):
         self._see_current_move()
 
     def _analyse_position(self, *position):
-        analysis = self.get_analysis(*position)
-        self._refresh_analysis_widget_from_database(analysis)
+        """Return True if position has been queued for engine analysis."""
         if self.game_analysis_in_progress:
             if not self.ui.uci.uci.is_positions_pending_empty():
                 return
             self.game_analysis_in_progress = False
+        analysis = self.get_analysis(*position)
         analysis.variations.clear()
 
         # Avoid "OSError: [WinError 535] Pipe connected"  at Python3.3 running
@@ -285,7 +286,9 @@ class Game(Score, EventBinding, AnalysisEventBinding):
             position = self.fen_tag_tuple_square_piece_map()
         else:
             position = self.tagpositionmap[self.current]
-        self._analyse_position(*position)
+        self._refresh_analysis_widget_from_database(
+            self.get_analysis(*position)
+        )
 
     def set_and_tag_item_text(self, reset_undo=False):
         """Display the game as board and moves.
@@ -336,15 +339,39 @@ class Game(Score, EventBinding, AnalysisEventBinding):
             self.score.edit_reset()
         self.board.set_board(self.fen_tag_square_piece_map())
         self.score.tag_add(MOVETEXT_INDENT_TAG, "1.0", tkinter.END)
-        self._analyse_position(*self.fen_tag_tuple_square_piece_map())
+        self._refresh_analysis_widget_from_database(
+            self.get_analysis(*self.fen_tag_tuple_square_piece_map())
+        )
 
-    def _analyse_game(self):
+    def _analyse_game(self, event=None):
         """Analyse all positions in game using all active engines."""
+        del event
         uci = self.ui.uci.uci
+        if not uci.uci_drivers_index:
+            tkinter.messagebox.showinfo(
+                parent=self.ui.get_toplevel(),
+                title=EventSpec.analyse_game[1],
+                message="No Chess Engines running",
+            )
+            return
+        if tkinter.messagebox.YES != tkinter.messagebox.askquestion(
+            parent=self.ui.get_toplevel(),
+            title=EventSpec.analyse_game[1],
+            message="Please confirm 'analyse all' request",
+        ):
+            return
         sas = self.analysis.score
         sga = self.get_analysis
         self.game_analysis_in_progress = True
         for value in self.tagpositionmap.values():
+            # Only known case is for Game Termination Marker in a game
+            # being entered via 'Game | New Game' menu option.
+            # It is not clear how to set things so this case behaves like
+            # editing a game from the database: where this test is not
+            # needed.
+            if value is None:
+                continue
+
             analysis = sga(*value)
             analysis.variations.clear()
 
@@ -368,6 +395,35 @@ class Game(Score, EventBinding, AnalysisEventBinding):
             #    break
             uci.ui_analysis_queue.put((sas, analysis))
 
+    def _analyse_game_position(self, event=None):
+        """Analyse game position associated with current token."""
+        del event
+        uci = self.ui.uci.uci
+        if not uci.uci_drivers_index:
+            message = "No Chess Engines running"
+        elif self.current not in self.tagpositionmap:
+            message = "Current position not mapped"
+        elif self.tagpositionmap[self.current] is None:
+            message = "Current position is None"
+        elif not self.ui.uci.uci.is_positions_pending_empty():
+            message = "".join(
+                (
+                    "Current position not queued for analysis : ",
+                    "try again when queue is empty",
+                )
+            )
+        else:
+            self._analyse_position(*self.tagpositionmap[self.current])
+            message = None
+        if message is not None:
+            tkinter.messagebox.showinfo(
+                parent=self.ui.get_toplevel(),
+                title=EventSpec.analyse_game_position[1],
+                message=message,
+            )
+        # Prevent some other binding moving cursor up one line as well.
+        return "break"
+
     def hide_game_analysis(self):
         """Hide the widgets which show analysis from chess engines."""
         self.analysis.score.grid_remove()
@@ -421,6 +477,12 @@ class Game(Score, EventBinding, AnalysisEventBinding):
             widget.tag_configure(ANALYSIS_PGN_TAGS_TAG, elide=tkinter.TRUE)
         self._see_current_move()
 
+    def toggle_game_structured_comments(self):
+        """Toggle display of '{[%<any>]}' comments in game score widgets."""
+        self._suppress_comment = self.ui.suppress_structured_comment
+        self.clear_score()
+        self.set_and_tag_item_text(reset_undo=False)
+
     def toggle_game_move_numbers(self):
         """Toggle display of move numbers in game score widgets."""
         widget = self.score
@@ -443,6 +505,17 @@ class Game(Score, EventBinding, AnalysisEventBinding):
             new_text.append(UNKNOWN_RESULT)
             if move_played:
                 new_text.insert(0, move_played)
+                new_text.insert(
+                    0,
+                    "".join(
+                        (
+                            START_TAG,
+                            TAG_SETUP,
+                            '"1',
+                            END_TAG.join('"\n'),
+                        )
+                    ),
+                )
                 new_text.insert(
                     0,
                     "".join(
@@ -451,7 +524,8 @@ class Game(Score, EventBinding, AnalysisEventBinding):
                             TAG_FEN,
                             '"',
                             analysis.position,
-                            END_TAG.join('"\n'),
+                            '"',
+                            END_TAG,
                         )
                     ),
                 )
@@ -493,7 +567,7 @@ class Game(Score, EventBinding, AnalysisEventBinding):
         # When a database is open the analysis is refreshed from the database
         # while checking if that analysis is up-to-date compared with the depth
         # and multiPV parameters held in self.uci.uci UCI object.
-        if self.ui.database is None:
+        if self.ui.is_database_access_inhibited():
             self._refresh_analysis_widget_from_engine(analysis)
             return
 
@@ -569,6 +643,9 @@ class Game(Score, EventBinding, AnalysisEventBinding):
     def _set_primary_activity_bindings(self, switch=True):
         """Delegate then set board pointer move navigation bindings."""
         super()._set_primary_activity_bindings(switch=switch)
+        self.set_event_bindings_score(
+            self._get_engine_analysis_events(), switch=switch
+        )
         if self.score is self.takefocus_widget:
             self.set_board_pointer_move_bindings(switch=switch)
         else:
@@ -703,12 +780,19 @@ class Game(Score, EventBinding, AnalysisEventBinding):
         popup = super()._create_primary_activity_popup()
         self._set_popup_bindings(
             popup,
-            ((EventSpec.analyse_game, self._analyse_game),),
+            self._get_engine_analysis_events(),
             index=self.export_popup_label,
         )
         self._create_widget_navigation_submenu_for_popup(popup)
         return popup
 
+    def _get_engine_analysis_events(self):
+        """Return tuple of engine analysis keypresses and callbacks."""
+        return (
+            (EventSpec.analyse_game, self._analyse_game),
+            (EventSpec.analyse_game_position, self._analyse_game_position),
+        )
+
     def _create_select_move_popup(self):
         """Delegate then add navigation submenu and return popup menu."""
         popup = super()._create_select_move_popup()
