@@ -4,6 +4,9 @@
 
 """Customise delete toplevel to delete chess game record."""
 
+import ast
+import tkinter
+
 from solentware_grid.gui.datadelete import DataDelete
 
 from pgn_read.core.parser import PGN
@@ -11,6 +14,7 @@ from pgn_read.core.constants import TAG_WHITE, TAG_BLACK
 
 from .gametoplevel import GameToplevel
 from .toplevelpgn import DeletePGNToplevel
+from ..core import utilities
 
 
 class GameDbDelete(DeletePGNToplevel, DataDelete):
@@ -44,6 +48,22 @@ class GameDbDelete(DeletePGNToplevel, DataDelete):
             title="",
         )
         self._initialize()
+        if utilities.is_game_import_in_progress_txn(
+            self.ui.database, self.object
+        ):
+            tkinter.messagebox.showinfo(
+                parent=parent,
+                title="Game import not complete",
+                message="".join(
+                    (
+                        "The selected game is displayed but attempts ",
+                        "to delete the game will be ",
+                        "rejected because some stages of importing this ",
+                        "game have not been completed.",
+                    )
+                ),
+            )
+            self.blockchange = True
 
     @property
     def ui_base_table(self):
@@ -65,7 +85,9 @@ class GameDbDelete(DeletePGNToplevel, DataDelete):
         self._set_default_source_for_object(object_)
         view.set_position_analysis_data_source()
         view.collected_game = next(
-            PGN(game_class=view.gameclass).read_games(object_.get_srvalue())
+            PGN(game_class=view.gameclass).read_games(
+                ast.literal_eval(object_.get_srvalue()[0])
+            )
         )
         view.set_and_tag_item_text()
 
@@ -111,6 +133,22 @@ class GameDbDelete(DeletePGNToplevel, DataDelete):
     # mark...recalculated starts and commits a transaction unconditionally.
     # No harm in using the same default as the 'super()' method.
     def delete(self, commit=True):
-        """Mark partial position records for recalculation and return key."""
-        self.datasource.dbhome.mark_partial_positions_to_be_recalculated()
+        """Mark CQL query records for recalculation and return key.
+
+        If commit evaluates False caller is responsible for evaluating
+        CQL queries on the changes.
+
+        """
+        dbhome = self.datasource.dbhome
+        dbhome.mark_games_evaluated(
+            allexceptkey=(
+                self.object.key.recno if self.object is not None else None
+            )
+        )
+        dbhome.mark_all_cql_statements_not_evaluated()
+        if commit:
+            dbhome.remove_game_key_from_all_cql_query_match_lists(
+                self.object.key.recno
+            )
         super().delete(commit=commit)
+        dbhome.clear_cql_queries_pending_evaluation()
