@@ -4,6 +4,8 @@
 
 """Customise show toplevel to display chess game record."""
 
+import ast
+
 from solentware_grid.gui.datashow import DataShow
 
 from pgn_read.core.parser import PGN
@@ -66,7 +68,9 @@ class GameDbShow(ShowPGNToplevel, DataShow):
         self._set_default_source_for_object(object_)
         view.set_position_analysis_data_source()
         view.collected_game = next(
-            PGN(game_class=view.gameclass).read_games(object_.get_srvalue())
+            PGN(game_class=view.gameclass).read_games(
+                ast.literal_eval(object_.get_srvalue()[0])
+            )
         )
         view.set_and_tag_item_text()
 
