@@ -43,80 +43,80 @@ class ChessDBrowGame(GamePosition, AllRow, ChessDBrecordGameTags, DataRow):
     header_specification = [
         {
             WIDGET: tkinter.Label,
-            WIDGET_CONFIGURE: dict(
-                text=TAG_WHITE,
-                anchor=tkinter.W,
-                padx=0,
-                pady=1,
-                font="TkDefaultFont",
-            ),
-            GRID_CONFIGURE: dict(column=0, sticky=tkinter.EW),
-            GRID_COLUMNCONFIGURE: dict(weight=1, uniform="player"),
+            WIDGET_CONFIGURE: {
+                "text": TAG_WHITE,
+                "anchor": tkinter.W,
+                "padx": 0,
+                "pady": 1,
+                "font": "TkDefaultFont",
+            },
+            GRID_CONFIGURE: {"column": 0, "sticky": tkinter.EW},
+            GRID_COLUMNCONFIGURE: {"weight": 1, "uniform": "player"},
             ROW: 0,
         },
         {
             WIDGET: tkinter.Label,
-            WIDGET_CONFIGURE: dict(
-                text=TAG_RESULT,
-                anchor=tkinter.CENTER,
-                padx=0,
-                pady=1,
-                font="TkDefaultFont",
-            ),
-            GRID_CONFIGURE: dict(column=1, sticky=tkinter.EW),
-            GRID_COLUMNCONFIGURE: dict(weight=1, uniform="score"),
+            WIDGET_CONFIGURE: {
+                "text": TAG_RESULT,
+                "anchor": tkinter.CENTER,
+                "padx": 0,
+                "pady": 1,
+                "font": "TkDefaultFont",
+            },
+            GRID_CONFIGURE: {"column": 1, "sticky": tkinter.EW},
+            GRID_COLUMNCONFIGURE: {"weight": 1, "uniform": "score"},
             ROW: 0,
         },
         {
             WIDGET: tkinter.Label,
-            WIDGET_CONFIGURE: dict(
-                text=TAG_BLACK,
-                anchor=tkinter.W,
-                padx=0,
-                pady=1,
-                font="TkDefaultFont",
-            ),
-            GRID_CONFIGURE: dict(column=2, sticky=tkinter.EW),
-            GRID_COLUMNCONFIGURE: dict(weight=1, uniform="player"),
+            WIDGET_CONFIGURE: {
+                "text": TAG_BLACK,
+                "anchor": tkinter.W,
+                "padx": 0,
+                "pady": 1,
+                "font": "TkDefaultFont",
+            },
+            GRID_CONFIGURE: {"column": 2, "sticky": tkinter.EW},
+            GRID_COLUMNCONFIGURE: {"weight": 1, "uniform": "player"},
             ROW: 0,
         },
         {
             WIDGET: tkinter.Label,
-            WIDGET_CONFIGURE: dict(
-                text=TAG_EVENT,
-                anchor=tkinter.W,
-                padx=0,
-                pady=1,
-                font="TkDefaultFont",
-            ),
-            GRID_CONFIGURE: dict(column=3, sticky=tkinter.EW),
-            GRID_COLUMNCONFIGURE: dict(weight=1, uniform="event"),
+            WIDGET_CONFIGURE: {
+                "text": TAG_EVENT,
+                "anchor": tkinter.W,
+                "padx": 0,
+                "pady": 1,
+                "font": "TkDefaultFont",
+            },
+            GRID_CONFIGURE: {"column": 3, "sticky": tkinter.EW},
+            GRID_COLUMNCONFIGURE: {"weight": 1, "uniform": "event"},
             ROW: 0,
         },
         {
             WIDGET: tkinter.Label,
-            WIDGET_CONFIGURE: dict(
-                text=TAG_DATE,
-                anchor=tkinter.W,
-                padx=0,
-                pady=1,
-                font="TkDefaultFont",
-            ),
-            GRID_CONFIGURE: dict(column=4, sticky=tkinter.EW),
-            GRID_COLUMNCONFIGURE: dict(weight=1, uniform="date"),
+            WIDGET_CONFIGURE: {
+                "text": TAG_DATE,
+                "anchor": tkinter.W,
+                "padx": 0,
+                "pady": 1,
+                "font": "TkDefaultFont",
+            },
+            GRID_CONFIGURE: {"column": 4, "sticky": tkinter.EW},
+            GRID_COLUMNCONFIGURE: {"weight": 1, "uniform": "date"},
             ROW: 0,
         },
         {
             WIDGET: tkinter.Label,
-            WIDGET_CONFIGURE: dict(
-                text="Tags",
-                anchor=tkinter.W,
-                padx=10,
-                pady=1,
-                font="TkDefaultFont",
-            ),
-            GRID_CONFIGURE: dict(column=5, sticky=tkinter.EW),
-            GRID_COLUMNCONFIGURE: dict(weight=4, uniform="tags"),
+            WIDGET_CONFIGURE: {
+                "text": "Tags",
+                "anchor": tkinter.W,
+                "padx": 10,
+                "pady": 1,
+                "font": "TkDefaultFont",
+            },
+            GRID_CONFIGURE: {"column": 5, "sticky": tkinter.EW},
+            GRID_COLUMNCONFIGURE: {"weight": 4, "uniform": "tags"},
             ROW: 0,
         },
     ]
@@ -134,68 +134,68 @@ class ChessDBrowGame(GamePosition, AllRow, ChessDBrecordGameTags, DataRow):
         self.row_specification = [
             {
                 WIDGET: tkinter.Label,
-                WIDGET_CONFIGURE: dict(
-                    anchor=tkinter.W,
-                    font=constants.LISTS_OF_GAMES_FONT,
-                    pady=1,
-                    padx=0,
-                ),
-                GRID_CONFIGURE: dict(column=0, sticky=tkinter.EW),
+                WIDGET_CONFIGURE: {
+                    "anchor": tkinter.W,
+                    "font": constants.LISTS_OF_GAMES_FONT,
+                    "pady": 1,
+                    "padx": 0,
+                },
+                GRID_CONFIGURE: {"column": 0, "sticky": tkinter.EW},
                 ROW: 0,
             },
             {
                 WIDGET: tkinter.Label,
-                WIDGET_CONFIGURE: dict(
-                    anchor=tkinter.CENTER,
-                    font=constants.LISTS_OF_GAMES_FONT,
-                    pady=1,
-                    padx=0,
-                ),
-                GRID_CONFIGURE: dict(column=1, sticky=tkinter.EW),
+                WIDGET_CONFIGURE: {
+                    "anchor": tkinter.CENTER,
+                    "font": constants.LISTS_OF_GAMES_FONT,
+                    "pady": 1,
+                    "padx": 0,
+                },
+                GRID_CONFIGURE: {"column": 1, "sticky": tkinter.EW},
                 ROW: 0,
             },
             {
                 WIDGET: tkinter.Label,
-                WIDGET_CONFIGURE: dict(
-                    anchor=tkinter.W,
-                    font=constants.LISTS_OF_GAMES_FONT,
-                    pady=1,
-                    padx=0,
-                ),
-                GRID_CONFIGURE: dict(column=2, sticky=tkinter.EW),
+                WIDGET_CONFIGURE: {
+                    "anchor": tkinter.W,
+                    "font": constants.LISTS_OF_GAMES_FONT,
+                    "pady": 1,
+                    "padx": 0,
+                },
+                GRID_CONFIGURE: {"column": 2, "sticky": tkinter.EW},
                 ROW: 0,
             },
             {
                 WIDGET: tkinter.Label,
-                WIDGET_CONFIGURE: dict(
-                    anchor=tkinter.W,
-                    font=constants.LISTS_OF_GAMES_FONT,
-                    pady=1,
-                    padx=0,
-                ),
-                GRID_CONFIGURE: dict(column=3, sticky=tkinter.EW),
+                WIDGET_CONFIGURE: {
+                    "anchor": tkinter.W,
+                    "font": constants.LISTS_OF_GAMES_FONT,
+                    "pady": 1,
+                    "padx": 0,
+                },
+                GRID_CONFIGURE: {"column": 3, "sticky": tkinter.EW},
                 ROW: 0,
             },
             {
                 WIDGET: tkinter.Label,
-                WIDGET_CONFIGURE: dict(
-                    anchor=tkinter.W,
-                    font=constants.LISTS_OF_GAMES_FONT,
-                    pady=1,
-                    padx=0,
-                ),
-                GRID_CONFIGURE: dict(column=4, sticky=tkinter.EW),
+                WIDGET_CONFIGURE: {
+                    "anchor": tkinter.W,
+                    "font": constants.LISTS_OF_GAMES_FONT,
+                    "pady": 1,
+                    "padx": 0,
+                },
+                GRID_CONFIGURE: {"column": 4, "sticky": tkinter.EW},
                 ROW: 0,
             },
             {
                 WIDGET: tkinter.Label,
-                WIDGET_CONFIGURE: dict(
-                    anchor=tkinter.W,
-                    font=constants.LISTS_OF_GAMES_FONT,
-                    pady=1,
-                    padx=10,
-                ),
-                GRID_CONFIGURE: dict(column=5, sticky=tkinter.EW),
+                WIDGET_CONFIGURE: {
+                    "anchor": tkinter.W,
+                    "font": constants.LISTS_OF_GAMES_FONT,
+                    "pady": 1,
+                    "padx": 10,
+                },
+                GRID_CONFIGURE: {"column": 5, "sticky": tkinter.EW},
                 ROW: 0,
             },
         ]
@@ -248,7 +248,7 @@ def chess_db_row_game(chessui):
 
     chessui is a chess_ui.ChessUI instance.
 
-    The returned function takes a ChessDatabase instance as it's argument.
+    The returned function takes a Database instance as it's argument.
     """
 
     def make_position(database=None):
