@@ -58,7 +58,7 @@ class Query(QueryText, EventBinding):
         """Create Frame , delegate to superclass, and set geometry manager."""
         del boardfont
         panel = tkinter.Frame(
-            master=master, cnf=dict(borderwidth=2, relief=tkinter.RIDGE)
+            master=master, cnf={"borderwidth": 2, "relief": tkinter.RIDGE}
         )
         panel.grid_propagate(False)
         super().__init__(
