@@ -33,6 +33,7 @@ from solentware_bind.gui.bindings import Bindings
 
 from .query import Query
 from .queryedit import QueryEdit
+from ..core import utilities
 from ..core.chessrecord import ChessDBrecordQuery
 from .eventspec import EventSpec
 from .display import Display
@@ -85,7 +86,6 @@ class _QueryDisplay(
             self.set_data_source(self.ui.base_selections.get_data_source())
         self.sourceobject = sourceobject
         self.insertonly = sourceobject is None
-        self.recalculate_after_edit = sourceobject
 
     @property
     def ui_displayed_items(self):
@@ -174,7 +174,7 @@ class _QueryDisplay(
 
         # This should see if game selection rule with same name already exists,
         # after checking for database open, and offer option to insert anyway.
-        if self.ui.database is None:
+        if self.ui.is_database_access_inhibited():
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
                 title="Insert Game Selection Rule",
@@ -276,7 +276,7 @@ class _QueryDisplay(
             )
             return
         editor = RecordEdit(updater, None)
-        editor.set_data_source(datasource, editor.on_data_change)
+        editor.set_data_source(source=datasource)
         updater.set_database(editor.get_data_source().dbhome)
         updater.key.recno = None  # 0
         editor.put()
@@ -341,12 +341,10 @@ class _QueryDisplay(
         but not as a consequence of updating the database.
         """
         if instance.newrecord:
-
             # Editing an existing record.
             key = instance.newrecord.key
 
         else:
-
             # Inserting a new record.
             key = instance.key
 
@@ -386,18 +384,37 @@ class _QueryDisplay(
     def _process_and_set_selection_rule_list(self, event=None):
         """Display games matching edited game selection rule."""
         del event
+        if self.ui.is_database_access_inhibited():
+            tkinter.messagebox.showinfo(
+                parent=self.ui.get_toplevel(),
+                title="List Selection Rule Games",
+                message="No chess database open",
+            )
+            return "break"
+        if utilities.is_import_in_progress_txn(self.ui.database):
+            tkinter.messagebox.showinfo(
+                parent=self.ui.get_toplevel(),
+                title="List Selection Rule Games",
+                message="".join(
+                    (
+                        "Cannot list games for rule because an ",
+                        "interrupted PGN import exists",
+                    )
+                ),
+            )
+            return "break"
         if self.ui.base_games.datasource:
             self.query_statement.set_database(
                 self.ui.base_games.datasource.dbhome
             )
         try:
             self.query_statement.process_query_statement(
-                self.score.get("1.0", tkinter.END)
+                self.get_newline_delimited_title_and_text()
             )
         except WhereError as exc:
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
-                title=" ".join(("Game Selection Rule Error")),
+                title="Game Selection Rule Error",
                 message=str(exc),
             )
             return "break"
@@ -426,7 +443,7 @@ class QueryDisplay(_QueryDisplay, Query, DataNotify):
     def _delete_item_database(self, event=None):
         """Remove game selection rule from database."""
         del event
-        if self.ui.database is None:
+        if self.ui.is_database_access_inhibited():
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
                 title="Delete Game Selection Rule",
@@ -509,7 +526,7 @@ class QueryDisplay(_QueryDisplay, Query, DataNotify):
                 )
                 return
         editor = RecordDelete(self.sourceobject)
-        editor.set_data_source(datasource, editor.on_data_change)
+        editor.set_data_source(source=datasource)
         editor.delete()
         tkinter.messagebox.showinfo(
             parent=self.ui.get_toplevel(),
@@ -552,7 +569,7 @@ class QueryDisplayEdit(EditText, QueryDisplayInsert):
     def _update_item_database(self, event=None):
         """Modify existing game selection rule record."""
         del event
-        if self.ui.database is None:
+        if self.ui.is_database_access_inhibited():
             tkinter.messagebox.showinfo(
                 parent=self.ui.get_toplevel(),
                 title="Edit Game Selection Rule",
@@ -696,7 +713,7 @@ class QueryDisplayEdit(EditText, QueryDisplayInsert):
             )
             return
         editor = RecordEdit(updater, original)
-        editor.set_data_source(datasource, editor.on_data_change)
+        editor.set_data_source(source=datasource)
         updater.set_database(editor.get_data_source().dbhome)
         original.set_database(editor.get_data_source().dbhome)
         updater.key.recno = original.key.recno
