@@ -27,7 +27,6 @@ from .game import Game
 
 
 class Repertoire(Game):
-
     """Chess repertoire game widget composed from Board and Text widgets.
 
     gameclass is passed to the superclass as the gameclass argument.  It
@@ -55,17 +54,18 @@ class Repertoire(Game):
     # Otherwise there is no point to this __init__ method.
     def __init__(self, gameclass=GameDisplayMoves, **ka):
         """Extend to display repertoire game."""
-        super(Repertoire, self).__init__(gameclass=gameclass, **ka)
+        super().__init__(gameclass=gameclass, **ka)
 
     # There is no point to a repertoire without RAVs so the options suppressing
     # RAVs are absent.
-    def get_all_export_events(self):
+    def _get_all_export_events(self):
+        """Return event specifications for Repertoire widget."""
         return (
             (
                 EventSpec.pgn_export_format_no_comments,
-                self.export_pgn_no_comments,
+                self._export_pgn_no_comments,
             ),
-            (EventSpec.pgn_export_format, self.export_pgn),
+            (EventSpec.pgn_export_format, self._export_pgn),
             (EventSpec.pgn_import_format, self.export_pgn_import_format),
-            (EventSpec.text_internal_format, self.export_text),
+            (EventSpec.text_internal_format, self._export_text),
         )
