@@ -48,7 +48,7 @@ class RepertoireDbEdit(EditPGNToplevel, DataEdit):
 
     pgn_score_name = "Repertoire"
     pgn_score_tags = EMPTY_REPERTOIRE_GAME
-    pgn_score_source = "No opening name"
+    pgn_score_source = ""
 
     def __init__(
         self,
@@ -67,9 +67,11 @@ class RepertoireDbEdit(EditPGNToplevel, DataEdit):
             oldobject=oldobject,
             newview=RepertoireToplevelEdit(master=parent, ui=ui),
             title="",
-            oldview=RepertoireToplevel(master=parent, ui=ui)
-            if showinitial
-            else showinitial,
+            oldview=(
+                RepertoireToplevel(master=parent, ui=ui)
+                if showinitial
+                else showinitial
+            ),
         )
         self._initialize()
 
@@ -133,4 +135,37 @@ class RepertoireDbEdit(EditPGNToplevel, DataEdit):
         if object_ is None:
             object_ = self.oldobject
         if object_ is not None:
-            object_.value.set_game_source(self.pgn_score_source)
+            object_.value.gamesource = self.pgn_score_source
+
+    def dialog_ok(self):
+        """Extend to adjust equality comparison of old and new versions.
+
+        Selection highlighting behaviour for repertoires is made same as
+        other item types.
+
+        """
+        # Problem arises because gamesource is treated differently in game
+        # and repertoire items.
+        # The selection highlight is removed if the referenced toplevel is
+        # changed, but not if some other item (same type with or without
+        # referenced toplevel) is highlighted.  This is inconsistent too,
+        # but arises from poor implementation of opening up a toplevel using
+        # just the pointer without affecting the selection highlight.  One
+        # solution is to change the intent so the pointer does affect the
+        # selection highlight when opening a toplevel, but not when closing
+        # a toplevel: most of behaviour at time of writing is consistent
+        # with this solution.
+        if self.oldobject and self.newobject:
+            oldv = self.oldobject.value
+            newv = self.newobject.value
+            # Force the test in DataEdit.dialog_ok to give desired outcome.
+            if oldv.collected_game == newv.collected_game:
+                newv.gamesource = oldv.gamesource
+        return super().dialog_ok()
+
+    def _construct_record_value(self, reference=None):
+        """Return record value for Repertoire record."""
+        # reference argument exists for compatibility with game classes
+        # which had the PGN source file reference added early 2024.
+        del reference
+        return repr(self.newview.get_score_error_escapes_removed())
