@@ -26,8 +26,11 @@ from ..core.filespec import (
 )
 from .eventspec import EventSpec
 
-_win32_platform = sys.platform == "win32"
+# Eyeball logic wants these attribute names to be same style.
+# pylint logic disagrees.
+_WIN32_PLATFORM = sys.platform == "win32"
 _freebsd_platform = sys.platform.startswith("freebsd")
+
 del sys
 
 
@@ -187,7 +190,7 @@ class UCI(Bindings):
         #             'this is expected if running under Wine.')))
         #    return
 
-        if _win32_platform:
+        if _WIN32_PLATFORM:
             filetypes = (("Chess Engines", "*.exe"),)
         else:
             filetypes = ()
@@ -625,6 +628,13 @@ class UCI(Bindings):
 
     def _show_engines(self):
         """Show Chess Engine Descriptions on database."""
+        if self.database is None or self.database.dbenv is None:
+            tkinter.messagebox.showinfo(
+                parent=self.menu_engines,
+                title="Show Engines",
+                message="No chess database open",
+            )
+            return
         if self._show_engines_toplevel is not None:
             tkinter.messagebox.showinfo(
                 parent=self.menu_engines,
@@ -742,7 +752,7 @@ class UCI(Bindings):
         pending_counts = []
         for engine, pending in self.uci.positions_pending.items():
             pending_counts.append(
-                (engine, sum([len(p) for p in pending.values()]))
+                (engine, sum(len(p) for p in pending.values()))
             )
         if not pending_counts:
             tkinter.messagebox.showinfo(
@@ -807,3 +817,17 @@ class UCI(Bindings):
             self._modify_command_menu_item(
                 "Clear Hash on", "Clear Hash off", self._set_clear_hash_off
             )
+
+    def is_database_access_inhibited(self):
+        """Return True if database cannot be accessed."""
+        if self.database is None or self.database.dbenv is None:
+            return True
+        return False
+
+    def is_database_update_inhibited(self):
+        """Return True if database cannot be updated."""
+        if self.is_database_access_inhibited():
+            return True
+        # Interrupted PGN game imports or CQL evaluations are not a reason
+        # to inhibited chess engine updates.
+        return False
