@@ -2,12 +2,11 @@
 # Copyright 2021 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Import directory of PGN files with apsw.chessapswdu to database."""
+"""Import directory of PGN files with apsw.database_du to database."""
 
 
 if __name__ == "__main__":
-
     from .directory_widget import DirectoryWidget
-    from ..apsw.chessapswdu import chess_database_du
+    from ..apsw.database_du import database_du
 
-    DirectoryWidget(chess_database_du, "apsw")
+    DirectoryWidget(database_du, "apsw")
