@@ -2,12 +2,11 @@
 # Copyright 2008 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Import directory of PGN files with dpt.chessdptdu to database."""
+"""Import directory of PGN files with dpt.database_du to database."""
 
 
 if __name__ == "__main__":
-
     from .directory_widget import DirectoryWidget
-    from ..dpt.chessdptdu import chess_dptdu
+    from ..dpt.database_du import database_du
 
-    DirectoryWidget(chess_dptdu, "dpt")
+    DirectoryWidget(database_du, "dpt")
