@@ -6,7 +6,7 @@
 
 This module contains FileWidget, the code common to the original *du_file
 modules; and file_du, a cut-down version of the chess_*du functions in the
-engine specific chess*du modules (db.chessdbdu for example).
+engine specific chess*du modules (db.database_du for example).
 """
 
 import tkinter
@@ -15,17 +15,18 @@ import os
 import tkinter.messagebox
 import tkinter.filedialog
 
-from ..core.chessrecord import ChessDBrecordGameImport
+from ..core.chessrecord import ChessDBrecordGameStore
+from ..core.filespec import GAMES_FILE_DEF
 
 
 def file_du(database, dbpath, pgnpath, **kwargs):
     """Open database, import games and close database."""
     cdb = database(dbpath, allowcreate=True, **kwargs)
-    importer = ChessDBrecordGameImport()
+    importer = ChessDBrecordGameStore()
     cdb.open_database()
     cdb.set_defer_update()
     s = open(pgnpath, "r", encoding="iso-8859-1")
-    importer.import_pgn(cdb, s, pgnpath)
+    importer.import_pgn(cdb, s, os.path.basename(pgnpath))
     s.close()
     cdb.do_final_segment_deferred_updates()
     cdb.unset_defer_update()
