@@ -2,12 +2,11 @@
 # Copyright 2020 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Import PGN file with unqlite.chessunqlitedu to database."""
+"""Import PGN file with unqlite.database_du to database."""
 
 
 if __name__ == "__main__":
-
     from .file_widget import FileWidget
-    from ..unqlite.chessunqlitedu import ChessDatabase
+    from ..unqlite.database_du import Database
 
-    FileWidget(ChessDatabase, "unqlite")
+    FileWidget(Database, "unqlite")
