@@ -10,7 +10,6 @@ Print names in games_Black and games_White records where the name with
 
 
 if __name__ == "__main__":
-
     import os
     import ast
     import re
@@ -22,11 +21,11 @@ if __name__ == "__main__":
         "games_White": "White",
     }
 
-    # bsddb removed from Python 3.n
+    # bsddb removed from Python 3 and bsddb3 up to 3.10 only.
     try:
+        from berkeleydb.db import DB
+    except ModuleNotFoundError:
         from bsddb3.db import DB
-    except ImportError:
-        from bsddb.db import DB
 
     import tkinter.filedialog
 
