@@ -20,6 +20,7 @@ from solentware_base.core.constants import (
 from ..core import filespec
 from ..core import chessrecord
 from ..core import utilities
+from ..core import constants
 from .. import ERROR_LOG, APPLICATION_NAME
 
 # Two million is chosen because it is close to the number of positions in
@@ -28,6 +29,11 @@ from .. import ERROR_LOG, APPLICATION_NAME
 # done for each segment.
 _MERGE_COMMIT_INTERVAL = 2000000
 
+# The piecesquare index fills the chosen map size increment for Symas LMDB
+# well before 2000000 entries added.  It also takes about 10 times as long
+# to process these entries compared with most other indicies.
+_SHORT_MERGE_COMMIT_INTERVAL = 200000
+
 
 def du_extract(
     cdb,
@@ -67,6 +73,25 @@ def du_extract(
 
     """
     del kwargs
+    cdb.start_read_only_transaction()
+    try:
+        expected_pgnpaths = cdb.get_import_pgn_file_tuple()
+        if expected_pgnpaths and set(expected_pgnpaths) != set(pgnpaths):
+            if reporter is not None:
+                reporter.append_text_only("")
+                reporter.append_text(
+                    "Unexpected PGN file names in import list"
+                )
+                reporter.append_text_only("")
+            return False
+    finally:
+        cdb.end_read_only_transaction()
+    if not expected_pgnpaths:
+        cdb.start_transaction()
+        try:
+            cdb.set_import_pgn_file_tuple(pgnpaths)
+        finally:
+            cdb.commit()
     importer = chessrecord.ChessDBrecordGameStore()
     for key in cdb.table.keys():
         if key == file:
@@ -743,7 +768,7 @@ def dump_indicies(
     if ignore is not None:
         indicies.difference_update(ignore)
     dump_directory = os.path.join(
-        cdb.home_directory,
+        cdb.get_merge_import_sort_area(),
         "_".join((os.path.basename(cdb.database_file), file)),
     )
     try:
@@ -939,7 +964,7 @@ def write_indicies_for_extracted_games(
             )
         )
     guard_file = os.path.join(
-        cdb.home_directory,
+        cdb.get_merge_import_sort_area(),
         "_".join(
             (os.path.basename(cdb.database_file), filespec.GAMES_FILE_DEF)
         ),
@@ -957,6 +982,9 @@ def write_indicies_for_extracted_games(
             reporter.append_text_only(os.path.dirname(guard_file))
         cdb.commit()
         return True
+    _remove_games_in_sequential_files_from_index_games(
+        cdb, index_games, reporter=reporter
+    )
     if not importer.write_index_entries_to_sequential_files(
         cdb,
         index_games,
@@ -973,6 +1001,60 @@ def write_indicies_for_extracted_games(
     return True
 
 
+def _remove_games_in_sequential_files_from_index_games(
+    cdb, index_games, reporter=None
+):
+    """Remove games fully referenced in sequential files from index_games.
+
+    Assume no games are fully refernced if maximum number of files in an
+    index directory is 1.
+
+    """
+    sort_area = os.path.join(
+        cdb.get_merge_import_sort_area(),
+        "_".join(
+            (os.path.basename(cdb.database_file), filespec.GAMES_FILE_DEF)
+        ),
+    )
+    if not os.path.isdir(sort_area):
+        return
+    indicies = set(cdb.specification[filespec.GAMES_FILE_DEF][SECONDARY])
+    directories = os.listdir(sort_area)
+    if indicies.difference(
+        directories + ["pgnfile", "cqleval", "import", "pgnerror", "cqlquery"]
+    ):
+        if reporter is not None:
+            reporter.append_text(
+                "Writing index entries for first segment was not completed."
+            )
+            reporter.append_text_only("")
+        return
+    segments = set()
+    for index in directories:
+        segments |= set(os.listdir(os.path.join(sort_area, index)))
+    if len(segments) < 2:
+        if reporter is not None:
+            reporter.append_text(
+                "Writing index entries for second segment was not started."
+            )
+            reporter.append_text_only("")
+        return
+    written = cdb.recordlist_record_number_range(
+        filespec.GAMES_FILE_DEF,
+        keyend=max(int(i) for i in segments) * SegmentSize.db_segment_size - 1,
+    )
+    try:
+        index_games.remove_recordset(written)
+        if reporter is not None:
+            reporter.append_text_only(
+                "Index entries for first "
+                + str(written.count_records())
+                + " records already writtem to sequential files."
+            )
+    finally:
+        written.close()
+
+
 def _delete_sorted_index_directory(index_directory):
     """Delete sorted index files in index_directory.
 
@@ -1088,10 +1170,14 @@ def load_indicies(
             )
             reporter.append_text_only("")
         return False
-    dump_directory = os.path.join(
-        cdb.home_directory,
-        "_".join((os.path.basename(cdb.database_file), file)),
-    )
+    cdb.start_read_only_transaction()
+    try:
+        dump_directory = os.path.join(
+            cdb.get_merge_import_sort_area(),
+            "_".join((os.path.basename(cdb.database_file), file)),
+        )
+    finally:
+        cdb.end_read_only_transaction()
     if not os.path.isdir(dump_directory):
         if reporter is not None:
             reporter.append_text_only("")
@@ -1141,6 +1227,10 @@ def load_indicies(
             continue
         cdb.delete_index(file, index)
         writer = cdb.merge_writer(file, index)
+        if index == filespec.PIECESQUARE_FIELD_DEF:
+            commit_interval = _SHORT_MERGE_COMMIT_INTERVAL
+        else:
+            commit_interval = _MERGE_COMMIT_INTERVAL
         for count, item in enumerate(cdb.next_sorted_item(index_directory)):
             if quit_event and quit_event.is_set():
                 if reporter is not None:
@@ -1152,7 +1242,7 @@ def load_indicies(
                 writer.close_cursor()
                 cdb.backout()
                 return False
-            if not count % _MERGE_COMMIT_INTERVAL:
+            if not count % commit_interval:
                 if count:
                     if reporter is not None:
                         reporter.append_text(
@@ -1230,6 +1320,18 @@ def load_indicies(
             os.rmdir(index_directory)
         except FileNotFoundError:
             pass
+        except OSError:
+            if reporter is not None:
+                reporter.append_text_only("")
+                reporter.append_text(
+                    "".join(
+                        (
+                            "Directory for '",
+                            index,
+                            "' not deleted: probably not empty.",
+                        )
+                    )
+                )
     try:
         os.remove(os.path.join(dump_directory, "0"))
     except FileNotFoundError:
@@ -1399,6 +1501,11 @@ def do_deferred_update(cdb, *args, reporter=None, file=None, **kwargs):
                 reporter.append_text_only("")
                 reporter.append_text("Import not completed.")
             return
+        cdb.start_transaction()
+        try:
+            cdb.delete_import_pgn_file_tuple()
+        finally:
+            cdb.commit()
     finally:
         cdb.close_database()
     if reporter is not None:
@@ -1449,6 +1556,11 @@ def do_reload_deferred_update(
                 )
             return
         if extract_done is None:
+            cdb.start_transaction()
+            try:
+                cdb.delete_import_pgn_file_tuple()
+            finally:
+                cdb.commit()
             if reporter is not None:
                 reporter.append_text_only("")
                 reporter.append_text("Import finished.")
@@ -1460,13 +1572,27 @@ def do_reload_deferred_update(
                 reporter.append_text_only("")
                 reporter.append_text("Dump existing indicies not completed.")
             return
-        if not load_indicies(
-            cdb, *args, reporter=reporter, file=file, ignore=ignore, **kwargs
-        ):
-            if reporter is not None:
-                reporter.append_text_only("")
-                reporter.append_text("Load indicies not completed.")
-            return
+        try:
+            if not load_indicies(
+                cdb,
+                *args,
+                reporter=reporter,
+                file=file,
+                ignore=ignore,
+                **kwargs,
+            ):
+                if reporter is not None:
+                    reporter.append_text_only("")
+                    reporter.append_text("Load indicies not completed.")
+                return
+        except Exception as exc:
+            _report_exception(cdb, reporter, exc)
+            raise
+        cdb.start_transaction()
+        try:
+            cdb.delete_import_pgn_file_tuple()
+        finally:
+            cdb.commit()
     finally:
         cdb.close_database()
     if reporter is not None:
@@ -1651,3 +1777,25 @@ class Alldu:
 
                 break
         del f, m
+
+    def get_merge_import_sort_area(self):
+        """Return sort area in application control or database directory."""
+        return self.get_application_control().get(
+            constants.SORT_AREA, super().get_merge_import_sort_area()
+        )
+
+    def get_import_pgn_file_tuple(self):
+        """Return PGN file list in application control or empty list."""
+        return self.get_application_control().get(constants.PGN_FILES, ())
+
+    def set_import_pgn_file_tuple(self, names):
+        """Return PGN file list in application control or empty list."""
+        appcontrol = self.get_application_control()
+        appcontrol[constants.PGN_FILES] = names
+        self.set_application_control(appcontrol)
+
+    def delete_import_pgn_file_tuple(self):
+        """Delete PGN file list from application control."""
+        appcontrol = self.get_application_control()
+        del appcontrol[constants.PGN_FILES]
+        self.set_application_control(appcontrol)
