@@ -17,10 +17,9 @@ def berkeleydb_du_splice_fix(home=None):
 
     """
     solentware_base.tools.berkeleydb_du_splice_fix.berkeleydb_du_splice_fix(
-        home=home, specification=filespec.FileSpec()
+        home=home, specification=filespec.make_filespec()
     )
 
 
 if __name__ == "__main__":
-
     berkeleydb_du_splice_fix()
